pub fn global_add_memory(start_vaddr: usize, size: usize) -> AllocResultExpand description
Add the given memory region to the global allocator.
pub fn global_add_memory(start_vaddr: usize, size: usize) -> AllocResultAdd the given memory region to the global allocator.