pub fn global_init(start_vaddr: usize, size: usize) -> AllocResultExpand description
Initializes the global allocator with the given memory region.
pub fn global_init(start_vaddr: usize, size: usize) -> AllocResultInitializes the global allocator with the given memory region.