Module tracking

Module tracking 

Tracking of memory usage, enabled with the tracking feature.

Structs

AllocationInfo
Metadata for each allocation made by the global allocator.

Functions

allocations_in
Visits all allocations made by the global allocator within the given generation range.
current_generation
Returns the current generation of the global allocator.
disable_tracking
Disables allocation tracking.
enable_tracking
Enables allocation tracking.
tracking_enabled
Returns whether allocation tracking is enabled.