pub fn allocations_in(range: Range<u64>, visitor: impl FnMut(&AllocationInfo))Expand description
Visits all allocations made by the global allocator within the given generation range.
pub fn allocations_in(range: Range<u64>, visitor: impl FnMut(&AllocationInfo))Visits all allocations made by the global allocator within the given generation range.