current_generation

Function current_generation 

pub fn current_generation() -> u64
Returns the current generation of the global allocator.

The generation is incremented every time a new allocation is made. It can be utilized to track the changes in the allocation state over time.

See allocations_in.