pub fn try_page_reclaim(num_pages: usize) -> usizeExpand description
Try to reclaim physical pages by invoking the registered callback. Returns the number of pages actually freed.
The SpinNoIrq guard is released before calling into the reclaim
function so that the reclaim path (and any evict listeners it
triggers) runs with interrupts enabled.