Tracking of memory usage, enabled with the tracking feature.
Structs
- Allocation
Info - Metadata for each allocation made by the global allocator.
Functions
- allocations_
in - Visits all allocations made by the global allocator within the given generation range.
- current_
generation - Returns the current generation of the global allocator.
- disable_
tracking - Disables allocation tracking.
- enable_
tracking - Enables allocation tracking.
- tracking_
enabled - Returns whether allocation tracking is enabled.